//
// Copyright (c) 2017 Dean Jackson <deanishe@deanishe.net>
//
// MIT Licence. See http://opensource.org/licenses/MIT
//
// Created on 2017-11-25
//

package main

import (
	aw "github.com/deanishe/awgo"
	"github.com/pkg/errors"
)

// "magic" action to open list of calendars
type calendarMagic struct{}

func (cm *calendarMagic) Keyword() string     { return "calendars" }
func (cm *calendarMagic) Description() string { return "Activate/deactivate calendars" }
func (cm *calendarMagic) RunText() string     { return "Opening calendar list…" }
func (cm *calendarMagic) Run() error          { return aw.NewAlfred().RunTrigger("calendars", "") }

// "magic" action to log in to a new account
type loginMagic struct{}

func (lm *loginMagic) Keyword() string     { return "login" }
func (lm *loginMagic) Description() string { return "Add a Google account" }
func (lm *loginMagic) RunText() string     { return "Opening Google signin page…" }
func (lm *loginMagic) Run() error {
	wf := aw.New()
	if err := wf.Alfred.RunTrigger("close", ""); err != nil {
		return errors.Wrap(err, "close Alfred")
	}

	acc, err := NewAccount("")
	if err != nil {
		return errors.Wrap(err, "magic: new account")
	}

	if err := acc.FetchCalendars(); err != nil {
		return errors.Wrap(err, "magic: fetch calendars")
	}

	// clear cached schedules now calendars have changed
	if err := clearEvents(); err != nil {
		return errors.Wrap(err, "clear cached events")
	}

	// re-open workflow configuration
	return wf.Alfred.RunTrigger("config", "")
}
